Method: Odfl#set_destination

Defined in:
lib/odfl.rb

#set_destination(zip, country = "USA") ⇒ Object

Allows the user to set the destination zip and country of the shipment

Attributes

  • zip - the zip code of the shipment destination

  • country - the country of the shipment destination defaults to USA

Usage

  1. Example Usage 1

quote = Odfl.new
quote.set_destination(20602)
  1. Example Usage 2

quote = Odfl.new
quote.set_destination(90210, "USA")


107
108
109
110
# File 'lib/odfl.rb', line 107

def set_destination(zip, country="USA")
  @destinationPostalCode = zip
  @destinationCountry = country
end